| dset | R Documentation |
Fill a vector or matrix with a constant value
dset(N = NULL, ALPHA, X, INCX = 1L)
N |
Optional integer specifying the number of elements to modify. Defaults to the length of 'X'. |
ALPHA |
Numeric scalar used to populate 'X'. |
X |
Double-precision vector, matrix or ['bigmemory::big.matrix'] to be filled in place. |
INCX |
Integer stride between successive elements of 'X'. |
Invisibly returns 'X' after modification.
x <- matrix(0, 2, 3)
dset(ALPHA = 5, X = x)
x
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.